# Terraform does not support gateway API so we need to use the generic kubernetes_manifest type instead.
# https://github.com/hashicorp/terraform-provider-kubernetes/issues/2474

resource "kubernetes_manifest" "gateway" {
  count = var.ingress_type == "gateway" ? 1 : 0

  manifest = {
    "apiVersion" = "gateway.networking.k8s.io/v1"
    "kind"       = "Gateway"
    "metadata" = {
      "name"      = "${var.cluster.name}-gateway"
      "namespace" = var.main_k8s_namespace
    }
    "spec" = {
      "gatewayClassName" = var.public_ingress ? "gke-l7-gxlb" : "gke-l7-rilb"
      "listeners" = [
        {
          "name"     = "plain-http"
          "protocol" = "HTTP"
          "port"     = 80
          "allowedRoutes" = {
            "kinds" = [
              {
                "kind" = "HTTPRoute"
              }
            ]
            "namespaces" = {
              "from" : "All"
            }
          }
        }
      ]
    }
  }

  depends_on = [time_sleep.wait_service_cleanup, var.cluster]
}

resource "kubernetes_manifest" "httproute" {
  for_each = var.ingress_type == "gateway" ? { for k, v in kubernetes_service_v1.default : k => v } : {}

  manifest = {
    "apiVersion" = "gateway.networking.k8s.io/v1"
    "kind"       = "HTTPRoute"
    "metadata" = {
      "name"      = "${var.cluster.name}-${each.value.metadata[0].name}"
      "namespace" = var.main_k8s_namespace
    }
    "spec" = {
      "parentRefs" = [
        {
          "name" : kubernetes_manifest.gateway[0].manifest.metadata.name
          "namespace" : kubernetes_manifest.gateway[0].manifest.metadata.namespace
        }
      ]
      "hostnames" = [trimsuffix("${each.value.metadata[0].name}.${var.cluster.name}.${var.dns_managed_zone.dns_name}", ".")]
      "rules" = [
        {
          "backendRefs" = [
            {
              "name" = each.value.metadata[0].name
              "port" = 80
            },
          ]
          "matches" = [
            {
              "path" = {
                "type"  = "PathPrefix"
                "value" = "/"
              }
            },
          ]
        }
      ]
    }
  }

  depends_on = [time_sleep.wait_service_cleanup, var.cluster]
}
