# apiVersion: networking.k8s.io/v1
# kind: IngressClass
# metadata:
#   name: nginx-public
#   annotations:
#     ingressclass.kubernetes.io/is-default-class: "true"
# spec:
#   controller: k8s.io/ingress-nginx

module "nginx_ingress_controller" {
  count  = var.ingress_type == "nginx" ? 1 : 0
  source = "../nginx_ingress_controller"
}

resource "kubernetes_ingress_v1" "ingress_nginx" {
  for_each = var.ingress_type == "nginx" ? { for k, v in kubernetes_service_v1.default : k => v } : {}

  metadata {
    name = "${var.cluster.name}-${each.value.metadata[0].name}"
    annotations = {
      "kubernetes.io/ingress.class" = var.public_ingress ? "gce" : "gce-internal"
    }
  }

  spec {
    rule {
      host = trimsuffix("${each.value.metadata[0].name}.${var.cluster.name}.${var.dns_managed_zone.dns_name}", ".")
      http {
        path {
          path = "/"
          backend {
            service {
              name = each.value.metadata[0].name
              port {
                number = 80
              }
            }
          }
        }
      }
    }
  }

  depends_on = [time_sleep.wait_service_cleanup]
}
